@@ -15,7 +15,6 @@ from pytest import mark, raises
 
 from wand.image import ClosedImageError, Image
 from wand.color import Color
-from wand.compat import PY3, text, text_type
 from wand.font import Font
 
 try:
@@ -70,7 +69,7 @@ def test_blank_image():
         assert img[10, 5] == gray
 
 
-def test_raw_image(fx_asset):
+def test_raw_image():
     b = b"".join([struct.pack("BBB", i, j, 0)
                   for i in range(256) for j in range(256)])
     with raises(ValueError):
@@ -82,54 +81,49 @@ def test_raw_image(fx_asset):
         assert img[0, 0] == Color('#000000')
         assert img[255, 255] == Color('#ffff00')
         assert img[64, 128] == Color('#804000')
-    with Image(filename=str(fx_asset.join('blob.rgb')),
-               depth=8, width=256, height=256, format="RGB") as img:
-        assert img.size == (256, 256)
-        assert img[0, 0] == Color('#000000')
-        assert img[255, 255] == Color('#ffff00')
-        assert img[64, 128] == Color('#804000')
 
 
-def test_clear_image(fx_asset):
+def test_clear_image():
     with Image() as img:
-        img.read(filename=str(fx_asset.join('mona-lisa.jpg')))
-        assert img.size == (402, 599)
+        img.read(filename='logo:')
+        assert img.size == (640, 480)
         img.clear()
         assert img.size == (0, 0)
-        img.read(filename=str(fx_asset.join('beach.jpg')))
-        assert img.size == (800, 600)
+        img.read(filename='wizard:')
+        assert img.size == (480, 640)
 
 
 def test_read_from_filename(fx_asset):
+    fpath = str(fx_asset.joinpath('mona-lisa.jpg'))
     with Image() as img:
-        img.read(filename=str(fx_asset.join('mona-lisa.jpg')))
+        img.read(filename=fpath)
         assert img.width == 402
         img.clear()
-        with fx_asset.join('mona-lisa.jpg').open('rb') as f:
+        with open(fpath, 'rb') as f:
             img.read(file=f)
             assert img.width == 402
             img.clear()
-        blob = fx_asset.join('mona-lisa.jpg').read('rb')
-        img.read(blob=blob)
-        assert img.width == 402
+        with open(fpath, 'rb') as f:
+            blob = f.read()
+            img.read(blob=blob)
+            assert img.width == 402
 
 
 @mark.skipif(not unicode_filesystem_encoding,
              reason='Unicode filesystem encoding needed')
-def test_read_from_unicode_filename(fx_asset, tmpdir):
+def test_read_from_unicode_filename(fx_asset, tmp_path):
     """https://github.com/emcconville/wand/issues/122"""
     filename = '모나리자.jpg'
-    if not PY3:
-        filename = filename.decode('utf-8')
-    path = os.path.join(text_type(tmpdir), filename)  # workaround py.path bug
-    shutil.copyfile(str(fx_asset.join('mona-lisa.jpg')), path)
+    src = str(fx_asset / 'mona-lisa.jpg')
+    dst = str(tmp_path / filename)
+    shutil.copyfile(src, dst)
     with Image() as img:
-        img.read(filename=text(path))
+        img.read(filename=dst)
         assert img.width == 402
 
 
 def test_read_with_colorspace(fx_asset):
-    fpath = str(fx_asset.join('cmyk.jpg'))
+    fpath = str(fx_asset.joinpath('cmyk.jpg'))
     with Image(filename=fpath,
                colorspace='srgb',
                units='pixelspercentimeter') as img:
@@ -146,72 +140,78 @@ def test_read_with_extract():
 
 def test_new_from_file(fx_asset):
     """Opens an image from the file object."""
-    with fx_asset.join('mona-lisa.jpg').open('rb') as f:
+    fpath = fx_asset.joinpath('mona-lisa.jpg')
+    with open(fpath, 'rb') as f:
         with Image(file=f) as img:
             assert img.width == 402
-    with raises(ClosedImageError):
-        img.wand
-    strio = io.BytesIO(fx_asset.join('mona-lisa.jpg').read('rb'))
-    with Image(file=strio) as img:
-        assert img.width == 402
-    strio.close()
-    with raises(ClosedImageError):
-        img.wand
-    with raises(TypeError):
-        Image(file='not file object')
+        with raises(ClosedImageError):
+            img.wand
+
+    with open(fpath, 'rb') as f:
+        strio = io.BytesIO(f.read())
+        with Image(file=strio) as img:
+            assert img.width == 402
+        strio.close()
+        with raises(ClosedImageError):
+            img.wand
+        with raises(TypeError):
+            Image(file='not file object')
 
 
 def test_new_from_filename(fx_asset):
     """Opens an image through its filename."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         assert img.width == 402
     with raises(ClosedImageError):
         img.wand
     with raises(IOError):
-        Image(filename=str(fx_asset.join('not-exists.jpg')))
+        Image(filename=str(fx_asset.joinpath('not-exists.jpg')))
 
 
 @mark.skipif(not unicode_filesystem_encoding,
              reason='Unicode filesystem encoding needed')
-def test_new_from_unicode_filename(fx_asset, tmpdir):
+def test_new_from_unicode_filename(fx_asset, tmp_path):
     """https://github.com/emcconville/wand/issues/122"""
     filename = '모나리자.jpg'
-    if not PY3:
-        filename = filename.decode('utf-8')
-    path = os.path.join(text_type(tmpdir), filename)  # workaround py.path bug
-    shutil.copyfile(str(fx_asset.join('mona-lisa.jpg')), path)
-    with Image(filename=text(path)) as img:
+    src = str(fx_asset / 'mona-lisa.jpg')
+    dst = str(tmp_path / filename)
+    shutil.copyfile(src, dst)
+    with Image(filename=dst) as img:
         assert img.width == 402
 
 
 def test_new_from_blob(fx_asset):
     """Opens an image from blob."""
-    blob = fx_asset.join('mona-lisa.jpg').read('rb')
-    with Image(blob=blob) as img:
-        assert img.width == 402
-    with raises(ClosedImageError):
-        img.wand
+    fpath = fx_asset.joinpath('mona-lisa.jpg')
+    with open(fpath, 'rb') as f:
+        blob = f.read()
+        with Image(blob=blob) as img:
+            assert img.width == 402
+        with raises(ClosedImageError):
+            img.wand
 
 
 def test_new_with_format(fx_asset):
-    blob = fx_asset.join('google.ico').read('rb')
-    with raises(Exception):
-        Image(blob=blob)
-    with Image(blob=blob, format='ico') as img:
-        assert img.size == (16, 16)
+    fpath = fx_asset.joinpath('google.ico')
+    with open(fpath, 'rb') as f:
+        blob = f.read()
+        with raises(Exception):
+            Image(blob=blob)
+        with Image(blob=blob, format='ico') as img:
+            assert img.size == (16, 16)
 
 
-def test_new_from_pseudo(fx_asset):
+def test_new_from_pseudo():
     with Image() as img:
         img.pseudo(10, 10, 'xc:none')
         assert img.size == (10, 10)
 
 
-def test_clone(fx_asset):
+def test_clone():
     """Clones the existing image."""
     funcs = (lambda img: Image(image=img),
              lambda img: img.clone())
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         for func in funcs:
             with func(img) as cloned:
                 assert img.wand is not cloned.wand
@@ -263,19 +263,21 @@ def test_image_swap():
 
 
 def test_ping_from_filename(fx_asset):
-    file_path = str(fx_asset.join('mona-lisa.jpg'))
+    file_path = str(fx_asset.joinpath('mona-lisa.jpg'))
     with Image.ping(filename=file_path) as img:
         assert img.size == (402, 599)
 
 
 def test_ping_from_blob(fx_asset):
-    blob = fx_asset.join('mona-lisa.jpg').read('rb')
-    with Image.ping(blob=blob) as img:
-        assert img.size == (402, 599)
+    fpath = fx_asset.joinpath('mona-lisa.jpg')
+    with open(fpath, 'rb') as f:
+        blob = f.read()
+        with Image.ping(blob=blob) as img:
+            assert img.size == (402, 599)
 
 
 def test_ping_from_file(fx_asset):
-    with fx_asset.join('mona-lisa.jpg').open('rb') as fd:
+    with fx_asset.joinpath('mona-lisa.jpg').open('rb') as fd:
         with Image.ping(file=fd) as img:
             assert img.size == (402, 599)
 
@@ -283,7 +285,7 @@ def test_ping_from_file(fx_asset):
 def test_save_to_filename(fx_asset):
     """Saves an image to the filename."""
     savefile = os.path.join(tempfile.mkdtemp(), 'savetest.jpg')
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as orig:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as orig:
         orig.save(filename=savefile)
         with raises(IOError):
             orig.save(filename=os.path.join(savefile, 'invalid.jpg'))
@@ -297,14 +299,14 @@ def test_save_to_filename(fx_asset):
 
 @mark.skipif(not unicode_filesystem_encoding,
              reason='Unicode filesystem encoding needed')
-def test_save_to_unicode_filename(fx_asset, tmpdir):
+def test_save_to_unicode_filename(fx_asset, tmp_path):
     filename = '모나리자.jpg'
-    if not PY3:
-        filename = filename.decode('utf-8')
-    path = os.path.join(text_type(tmpdir), filename)  # workaround py.path bug
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as orig:
-        orig.save(filename=path)
-    with Image(filename=path) as img:
+    src = str(fx_asset / 'mona-lisa.jpg')
+    dst = str(tmp_path / filename)
+    shutil.copyfile(src, dst)
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as orig:
+        orig.save(filename=dst)
+    with Image(filename=dst) as img:
         assert img.width == 402
 
 
@@ -312,7 +314,7 @@ def test_save_to_file(fx_asset):
     """Saves an image to the Python file object."""
     buffer = io.BytesIO()
     with tempfile.TemporaryFile() as savefile:
-        with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as orig:
+        with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as orig:
             orig.save(file=savefile)
             orig.save(file=buffer)
             with raises(TypeError):
@@ -331,7 +333,7 @@ def test_save_to_file(fx_asset):
 def test_save_full_animated_gif_to_file(fx_asset):
     """Save all frames of an animated to a Python file object."""
     temp_filename = os.path.join(tempfile.mkdtemp(), 'savetest.gif')
-    orig_filename = str(fx_asset.join('nocomments.gif'))
+    orig_filename = str(fx_asset.joinpath('nocomments.gif'))
     with open(temp_filename, 'w+b') as fp:
         with Image(filename=orig_filename) as orig:
             orig.save(file=fp)
@@ -345,7 +347,7 @@ def test_save_full_animated_gif_to_file(fx_asset):
 def test_save_error(fx_asset):
     filename = os.path.join(tempfile.mkdtemp(), 'savetest.jpg')
     fileobj = io.BytesIO()
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as orig:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as orig:
         with raises(TypeError):
             orig.save()
         with raises(TypeError):
@@ -354,7 +356,7 @@ def test_save_error(fx_asset):
 
 def test_make_blob(fx_asset):
     """Makes a blob string."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         with Image(blob=img.make_blob('png')) as img2:
             assert img2.size == (402, 599)
             assert img2.format == 'PNG'
@@ -376,6 +378,11 @@ def test_make_blob(fx_asset):
     with Image(blob=png, format='png') as img:
         assert img.size == (4, 4)
         assert img.format == 'PNG'
+    with Image() as img:
+        img.read(blob=pbm, format='pbm')
+        img.depth = 8
+        out = img.make_blob('R')
+        assert out[:2] == b'\xff\x00'
 
 
 def test_montage():
@@ -390,9 +397,9 @@ def test_montage():
         assert base.iterator_length() == 1
 
 
-def test_convert(fx_asset):
+def test_convert():
     """Converts the image format."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         with img.convert('png') as converted:
             assert converted.format == 'PNG'
             strio = io.BytesIO()
@@ -411,7 +418,7 @@ def test_iterate(fx_asset):
     """Uses iterator."""
     with Color('#000') as black:
         with Color('transparent') as transparent:
-            with Image(filename=str(fx_asset.join('croptest.png'))) as img:
+            with Image(filename=str(fx_asset.joinpath('croptest.png'))) as img:
                 for i, row in enumerate(img):
                     assert len(row) == 300
                     if i % 30:
@@ -430,16 +437,16 @@ def test_iterate(fx_asset):
                 assert i == 299
 
 
-def test_slice_clone(fx_asset):
+def test_slice_clone():
     """Clones using slicing."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         with img[:, :] as cloned:
             assert img.size == cloned.size
 
 
-def test_slice_invalid_types(fx_asset):
+def test_slice_invalid_types():
     """Slicing with invalid types should throw exceptions."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         with raises(TypeError):
             img['12']
         with raises(TypeError):
@@ -464,25 +471,21 @@ def test_slice_invalid_types(fx_asset):
             img['1', 0]
         with raises(TypeError):
             img[1, '0']
-    with Image(filename=str(fx_asset.join('croptest.png'))) as img:
+    with Image(filename='rose:') as img:
         with raises(IndexError):
             img[300, 300]
         with raises(IndexError):
             img[-301, -301]
 
 
-def test_index_pixel(fx_asset):
+def test_index_pixel():
     """Gets a pixel."""
-    with Image(filename=str(fx_asset.join('croptest.png'))) as img:
-        assert img[0, 0] == Color('transparent')
-        assert img[99, 99] == Color('transparent')
-        assert img[100, 100] == Color('black')
-        assert img[150, 150] == Color('black')
-        assert img[-200, -200] == Color('black')
-        assert img[-201, -201] == Color('transparent')
+    with Image(filename='rose:') as img:
+        assert isinstance(img[0, 0], Color)
+        assert isinstance(img[50, 25], Color)
 
 
-def test_index_pixel_set(fx_asset):
+def test_index_pixel_set():
     with Image(filename='rose:') as img:
         with Color('black') as dot:
             img[0, 0] = dot
@@ -511,7 +514,7 @@ def test_index_row(fx_asset):
     """Gets a row."""
     with Color('transparent') as transparent:
         with Color('black') as black:
-            with Image(filename=str(fx_asset.join('croptest.png'))) as img:
+            with Image(filename=str(fx_asset.joinpath('croptest.png'))) as img:
                 for c in img[0]:
                     assert c == transparent
                 for c in img[99]:
@@ -537,7 +540,7 @@ def test_index_row(fx_asset):
 
 def test_slice_crop(fx_asset):
     """Crops using slicing."""
-    with Image(filename=str(fx_asset.join('croptest.png'))) as img:
+    with Image(filename=str(fx_asset.joinpath('croptest.png'))) as img:
         with img[100:200, 100:200] as cropped:
             assert cropped.size == (100, 100)
             with Color('#000') as black:
@@ -559,36 +562,33 @@ def test_slice_crop(fx_asset):
 
 def test_equal(fx_asset):
     """Equals (``==``) and not equals (``!=``) operators."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as a:
-        with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as a2:
+    with Image(width=10, height=10, pseudo='xc:orange') as a:
+        with Image(width=10, height=10, pseudo='xc:orange') as a2:
             assert a == a2
             assert not (a != a2)
-        with Image(filename=str(fx_asset.join('sasha.jpg'))) as b:
+        with Image(width=10, height=10, pseudo='plasma:') as b:
             assert a != b
             assert not (a == b)
-        with a.convert('png') as a3:
-            assert a == a3
-            assert not (a != a3)
 
 
 def test_object_hash(fx_asset):
     """Gets :func:`hash()` of the image."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         a = hash(img)
         img.format = 'png'
         b = hash(img)
         assert a == b
 
 
-def test_issue_150(fx_asset, tmpdir):
+def test_issue_150(tmp_path):
     """Should not be terminated with segmentation fault.
 
     https://github.com/emcconville/wand/issues/150
 
     """
-    with Image(filename=str(fx_asset.join('tiger_hd-1920x1080.jpg'))) as img:
+    with Image(filename='rose:') as img:
         img.format = 'pjpeg'
-        with open(str(tmpdir.join('out.jpg')), 'wb') as f:
+        with open(str(tmp_path / 'out.jpg'), 'wb') as f:
             img.save(file=f)
 
 
